@@ -40,7 +40,7 @@
 #define CG_BUILD_BASESCOPE 0
 
 #define HDF5_INCLUDE_PATH ""
-#define HDF5_LIBRARY      "C:\a\msys64\clangarm64\lib\libhdf5.dll.a"
+#define HDF5_LIBRARY      "C:\M\msys64\clangarm64\lib\libhdf5.dll.a"
 
 #define HDF5_NEED_MPI     0
 #define HDF5_NEED_SZIP    0
